# kaziro

Kaziro Trading API Documentation

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

-   API version: 1.0.5
-   Package version: 1.0.0
-   Generator version: 7.9.0
-   Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage

### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```

(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:

```python
import kaziro
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```

(or `sudo python setup.py install` to install the package for all users)

Then import the package:

```python
import kaziro
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import kaziro
from kaziro.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = kaziro.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: APIKeyHeader
configuration.api_key['APIKeyHeader'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['APIKeyHeader'] = 'Bearer'


# Enter a context with an instance of the API client
with kaziro.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = kaziro.ChatApi(api_client)
    chat_creation_request = kaziro.ChatCreationRequest() # ChatCreationRequest |

    try:
        # Create Chat Message Endpoint
        api_response = api_instance.create_chat_message_endpoint_v1_exchange_chat_create_post(chat_creation_request)
        print("The response of ChatApi->create_chat_message_endpoint_v1_exchange_chat_create_post:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ChatApi->create_chat_message_endpoint_v1_exchange_chat_create_post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to _http://localhost_

| Class         | Method                                                                                                                                                                  | HTTP request                                | Description                     |
| ------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------- | ------------------------------- |
| _ChatApi_     | [**create_chat_message_endpoint_v1_exchange_chat_create_post**](docs/ChatApi.md#create_chat_message_endpoint_v1_exchange_chat_create_post)                              | **POST** /v1/exchange/chat/create           | Create Chat Message Endpoint    |
| _ChatApi_     | [**retrieve_chat_messages_endpoint_v1_exchange_chat_retrieve_get**](docs/ChatApi.md#retrieve_chat_messages_endpoint_v1_exchange_chat_retrieve_get)                      | **GET** /v1/exchange/chat/retrieve          | Retrieve Chat Messages Endpoint |
| _MarketApi_   | [**create_market_endpoint_v1_exchange_market_create_post**](docs/MarketApi.md#create_market_endpoint_v1_exchange_market_create_post)                                    | **POST** /v1/exchange/market/create         | Create Market Endpoint          |
| _MarketApi_   | [**retrieve_markets_endpoint_v1_exchange_market_retrieve_get**](docs/MarketApi.md#retrieve_markets_endpoint_v1_exchange_market_retrieve_get)                            | **GET** /v1/exchange/market/retrieve        | Retrieve Markets Endpoint       |
| _MarketApi_   | [**retrieve_ohlc_endpoint_v1_exchange_market_retrieve_ohlc_get**](docs/MarketApi.md#retrieve_ohlc_endpoint_v1_exchange_market_retrieve_ohlc_get)                        | **GET** /v1/exchange/market/retrieve/ohlc   | Retrieve Ohlc Endpoint          |
| _OrderApi_    | [**accept_orders_endpoint_v1_exchange_order_accept_post**](docs/OrderApi.md#accept_orders_endpoint_v1_exchange_order_accept_post)                                       | **POST** /v1/exchange/order/accept          | Accept orders                   |
| _OrderApi_    | [**create_market_endpoint_v1_exchange_order_create_post**](docs/OrderApi.md#create_market_endpoint_v1_exchange_order_create_post)                                       | **POST** /v1/exchange/order/create          | Place multiple orders           |
| _OrderApi_    | [**get_open_orders_endpoint_v1_exchange_order_retrieve_get**](docs/OrderApi.md#get_open_orders_endpoint_v1_exchange_order_retrieve_get)                                 | **GET** /v1/exchange/order/retrieve         | Retrieve open orders            |
| _OrderApi_    | [**request_default_replies_endpoint_v1_exchange_order_temporary_reply_post**](docs/OrderApi.md#request_default_replies_endpoint_v1_exchange_order_temporary_reply_post) | **POST** /v1/exchange/order/temporary/reply | Request default replies         |
| _PositionApi_ | [**get_positions_v1_exchange_position_retrieve_get**](docs/PositionApi.md#get_positions_v1_exchange_position_retrieve_get)                                              | **GET** /v1/exchange/position/retrieve      | Get positions                   |
| _UserApi_     | [**profile_retrieve_endpoint_v1_user_retrieve_get**](docs/UserApi.md#profile_retrieve_endpoint_v1_user_retrieve_get)                                                    | **GET** /v1/user/retrieve                   | Profile Retrieve Endpoint       |
| _WalletApi_   | [**wallet_info_endpoint_v1_wallet_retrieve_get**](docs/WalletApi.md#wallet_info_endpoint_v1_wallet_retrieve_get)                                                        | **GET** /v1/wallet/retrieve                 | Wallet Info Endpoint            |

## Documentation For Models

-   [AcceptOrdersRequest](docs/AcceptOrdersRequest.md)
-   [AcceptOrdersResponse](docs/AcceptOrdersResponse.md)
-   [AcceptedOrder](docs/AcceptedOrder.md)
-   [Chat](docs/Chat.md)
-   [ChatCreationRequest](docs/ChatCreationRequest.md)
-   [ChatRetrievalResponse](docs/ChatRetrievalResponse.md)
-   [ChatWithMarketAndOrder](docs/ChatWithMarketAndOrder.md)
-   [DefaultReplyOrder](docs/DefaultReplyOrder.md)
-   [ErrorResponse](docs/ErrorResponse.md)
-   [ErrorResponseDetail](docs/ErrorResponseDetail.md)
-   [HTTPValidationError](docs/HTTPValidationError.md)
-   [Market](docs/Market.md)
-   [MarketCreationResponse](docs/MarketCreationResponse.md)
-   [MarketDetail](docs/MarketDetail.md)
-   [MarketOHLCData](docs/MarketOHLCData.md)
-   [MarketPriceHistoryResponse](docs/MarketPriceHistoryResponse.md)
-   [MarketRetrievalResponse](docs/MarketRetrievalResponse.md)
-   [OHLCData](docs/OHLCData.md)
-   [OpenOrdersResponse](docs/OpenOrdersResponse.md)
-   [Order](docs/Order.md)
-   [OrderPair](docs/OrderPair.md)
-   [OrderRequest](docs/OrderRequest.md)
-   [OrderWithMarket](docs/OrderWithMarket.md)
-   [PlaceOrderResponse](docs/PlaceOrderResponse.md)
-   [Position](docs/Position.md)
-   [PositionResponse](docs/PositionResponse.md)
-   [PositionWithMarketAndOrders](docs/PositionWithMarketAndOrders.md)
-   [RequestDefaultRepliesRequest](docs/RequestDefaultRepliesRequest.md)
-   [RequestDefaultRepliesResponse](docs/RequestDefaultRepliesResponse.md)
-   [UserProfile](docs/UserProfile.md)
-   [UserProfileResponse](docs/UserProfileResponse.md)
-   [ValidationError](docs/ValidationError.md)
-   [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)
-   [Wallet](docs/Wallet.md)
-   [WalletInfoResponse](docs/WalletInfoResponse.md)

<a id="documentation-for-authorization"></a>

## Documentation For Authorization

Authentication schemes defined for the API:
<a id="APIKeyHeader"></a>

### APIKeyHeader

-   **Type**: API key
-   **API key parameter name**: Kaziro-API-Key
-   **Location**: HTTP header

## Author
